pub struct AbstractRing {
pub abstract_curve: AbstractCurve,
}Expand description
Base data shared by all GML ring geometry types (OGC 07-036 10.5.6).
A ring is a closed curve used as the boundary of a surface patch.
The only concrete ring type currently implemented is [LinearRing].
Fields
abstract_curve: AbstractCurveImplementations
Sourceimpl AbstractRing
impl AbstractRing
pub fn new() -> Self
pub fn from_abstract_curve(abstract_curve: AbstractCurve) -> Self