pub struct Polygon {
pub abstract_surface: AbstractSurface,
/* private fields */
}Fields
abstract_surface: AbstractSurfaceImplementations
Sourceimpl Polygon
impl Polygon
pub fn new( exterior: Option<AbstractRingProperty>, interior: impl IntoIterator<Item = AbstractRingProperty>, ) -> Result<Self, Error>
pub fn from_abstract_surface( abstract_surface: AbstractSurface, exterior: Option<AbstractRingProperty>, interior: impl IntoIterator<Item = AbstractRingProperty>, ) -> Self
pub fn exterior(&self) -> Option<&AbstractRingProperty>
pub fn set_exterior(&mut self, exterior: AbstractRingProperty)
pub fn set_exterior_opt(&mut self, exterior: Option<AbstractRingProperty>)
pub fn clear_exterior(&mut self)
pub fn interior(&self) -> &[AbstractRingProperty]
pub fn set_interior(&mut self, interior: Vec<AbstractRingProperty>)
pub fn push_interior(&mut self, ring: AbstractRingProperty)
pub fn extend_interiors( &mut self, rings: impl IntoIterator<Item = AbstractRingProperty>, )
Sourceimpl Polygon
impl Polygon
pub fn plane_equation(&self) -> Plane
Sourcepub fn area_3d(&self) -> Result<f64, Error>
pub fn area_3d(&self) -> Result<f64, Error>
Returns the net 3D area_3d of this polygon: exterior area_3d minus the sum of all interior hole area_3ds.
Errors
Returns Error::MissingExteriorRing if the polygon has no exterior ring property.
Returns Error::UnresolvedRingReference if the exterior ring or any interior hole
carries only an xlink:href that has not been resolved into an inline object.
pub fn points(&self) -> Vec<&DirectPosition>