pub struct PolygonPatch {
pub abstract_surface_patch: AbstractSurfacePatch,
/* private fields */
}Expand description
A planar polygon used as a surface patch inside a Surface.
PolygonPatch has the same geometry as Polygon
but is used exclusively as a building block of a patched surface rather than
as a standalone geometry element. Corresponds to gml:PolygonPatch in OGC 07-036 10.5.12.4.
Fields
abstract_surface_patch: AbstractSurfacePatchImplementations
Sourceimpl PolygonPatch
impl PolygonPatch
pub fn new( exterior: Option<AbstractRingProperty>, interior: impl IntoIterator<Item = AbstractRingProperty>, ) -> Self
pub fn from_abstract_surface_patch( abstract_surface_patch: AbstractSurfacePatch, exterior: Option<AbstractRingProperty>, interior: impl IntoIterator<Item = AbstractRingProperty>, ) -> Self
pub fn exterior(&self) -> Option<&AbstractRingProperty>
pub fn set_exterior(&mut self, exterior: AbstractRingProperty)
pub fn set_exterior_opt(&mut self, exterior: Option<AbstractRingProperty>)
pub fn clear_exterior(&mut self)
pub fn interior(&self) -> &[AbstractRingProperty]
pub fn set_interior(&mut self, interior: Vec<AbstractRingProperty>)
pub fn push_interior(&mut self, ring: AbstractRingProperty)
pub fn extend_interiors( &mut self, rings: impl IntoIterator<Item = AbstractRingProperty>, )
pub fn interpolation(&self) -> SurfaceInterpolation