pub struct Shell { /* private fields */ }Implementations
Sourceimpl Shell
impl Shell
pub fn new( members: impl IntoIterator<Item = AbstractSurfaceProperty>, ) -> Result<Self, Error>
pub fn from_abstract_surface( abstract_surface: AbstractSurface, members: impl IntoIterator<Item = AbstractSurfaceProperty>, ) -> Result<Self, Error>
Sourcepub fn members(&self) -> &[AbstractSurfaceProperty]
pub fn members(&self) -> &[AbstractSurfaceProperty]
Returns the bounding surface members of this solid.
Sourcepub fn set_members(
&mut self,
val: Vec<AbstractSurfaceProperty>,
) -> Result<(), Error>
pub fn set_members( &mut self, val: Vec<AbstractSurfaceProperty>, ) -> Result<(), Error>
pub fn push_member(&mut self, member: AbstractSurfaceProperty)
pub fn extend_members( &mut self, members: impl IntoIterator<Item = AbstractSurfaceProperty>, )
Sourceimpl Shell
impl Shell
pub fn points(&self) -> Vec<&DirectPosition>
Sourcepub fn volume_3d(&self) -> Result<f64, Error>
pub fn volume_3d(&self) -> Result<f64, Error>
Returns the volume of the closed solid bounded by this shell.
Uses the divergence theorem on the triangulated shell: V = |Σ a·(b×c)| / 6
per triangle. The shell must be closed and watertight for the result to be correct.
Errors
Propagates any Error::TriangulationFailed from triangulating the bounding surfaces.