pub struct TriangulatedSurface { /* private fields */ }Expand description
A 2-D surface composed exclusively of Triangle patches.
Corresponds to gml:TriangulatedSurface in OGC 07-036 10.5.11.4.
This type is the primary output of triangulation operations.
Implementations
Sourceimpl TriangulatedSurface
impl TriangulatedSurface
Sourcepub fn from_triangles(triangles: Vec<Triangle>) -> Result<Self, Error>
pub fn from_triangles(triangles: Vec<Triangle>) -> Result<Self, Error>
Creates a TriangulatedSurface from a flat list of triangles.
Errors
Returns Error::TooFewElements if triangles is empty.
Sourcepub fn from_triangulated_surfaces(
surfaces: Vec<TriangulatedSurface>,
) -> Result<Self, Error>
pub fn from_triangulated_surfaces( surfaces: Vec<TriangulatedSurface>, ) -> Result<Self, Error>
Merges multiple triangulated surfaces into one by combining all their patches.
Errors
Returns Error::TooFewElements if surfaces is empty.
Sourcepub fn triangles(&self) -> Vec<&Triangle>
pub fn triangles(&self) -> Vec<&Triangle>
Returns references to all Triangle patches in this surface.
pub fn points(&self) -> Vec<&DirectPosition>
pub fn area_3d(&self) -> Result<f64, Error>