pub struct Scale(/* private fields */);Expand description
A dimensionless scale factor with its unit of measure.
Corresponds to gml:ScaleType in ISO 19136 — a vacuous extension of
gml:MeasureType. The unit referenced by uom should be suitable for a
ratio, such as a percentage or a unitless factor.
Examples
use egml_core::model::measures::Scale;
let factor = Scale::new(0.5, "unity");
assert_eq!(factor.value(), 0.5);Implementations