pub trait HasAssociationAttributes {
// Required method
fn association(&self) -> &AssociationAttributes;
// Provided methods
fn href(&self) -> Option<&HRef> { ... }
fn local_id(&self) -> Option<&str> { ... }
fn nil_reason(&self) -> Option<&NilReason> { ... }
fn title(&self) -> Option<&str> { ... }
fn role(&self) -> Option<&str> { ... }
fn arcrole(&self) -> Option<&str> { ... }
fn show(&self) -> Option<&ShowType> { ... }
fn actuate(&self) -> Option<&ActuateType> { ... }
}Expand description
Read-only access to the gml:AssociationAttributeGroup on a property element.
Required Methods
fn association(&self) -> &AssociationAttributes
Provided Methods
Sourcefn nil_reason(&self) -> Option<&NilReason>
fn nil_reason(&self) -> Option<&NilReason>
gml:nilReason — explanation for a missing value.
Sourcefn role(&self) -> Option<&str>
fn role(&self) -> Option<&str>
xlink:role — URI identifying the semantic role of the linked resource.
Sourcefn show(&self) -> Option<&ShowType>
fn show(&self) -> Option<&ShowType>
xlink:show — how the linked resource should be presented on traversal.
Sourcefn actuate(&self) -> Option<&ActuateType>
fn actuate(&self) -> Option<&ActuateType>
xlink:actuate — when link traversal should be triggered.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".